# -*- coding: utf-8 -*-


def SymbolicConstant(in_str):
    """
    :param in_str:
    :return:
    """
    # type: "(str) -> str"
    in_str = in_str
    return in_str


DEG = SymbolicConstant('DEG')
RAD = SymbolicConstant('RAD')


# Variables with simple values

FALSE = False

OFF = 0

ON = 1

TRUE = True